==> hinemos_src-3.0.5.tar.gz: Hinemos_src-3.0.5/PerformanceEJB/src/com/clustercontrol/performance/monitor/bean/MonitorPerfCheckInfo.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */
package com.clustercontrol.performance.monitor.bean;

import com.clustercontrol.monitor.run.bean.MonitorCheckInfo;

/**
 * リソース監視情報のBeanクラス<BR>
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class MonitorPerfCheckInfo extends MonitorCheckInfo
{
	protected java.lang.String collectorId;
	protected java.lang.String itemCode;
	protected Long deviceIndex;
	protected java.lang.String deviceName;
	
	public MonitorPerfCheckInfo()
	{
	}
	
	/**
	 * 収集IDを取得します。
	 * @return 収集ID
	 */
	public java.lang.String getCollectorId() {
		return collectorId;
	}
	
	/**
	 * 収集IDを設定します。
	 * @param collectorId 収集ID
	 */
	public void setCollectorId(java.lang.String collectorId) {
		this.collectorId = collectorId;
	}
	
	/**
	 * デバイスのインデックスを取得します。
	 * @return デバイスのインデックス
	 */
	public Long getDeviceIndex() {
		return deviceIndex;
	}
	
	/**
	 * デバイスのインデックスを設定します。
	 * @param deviceIndex デバイスのインデックス
	 */
	public void setDeviceIndex(Long deviceIndex) {
		this.deviceIndex = deviceIndex;
	}
	
	/**
	 * デバイス名を取得します。
	 * @return デバイス名
	 */
	public java.lang.String getDeviceName() {
		return deviceName;
	}
	
	/**
	 * デバイス名を設定します。
	 * @param deviceName デバイス名
	 */
	public void setDeviceName(java.lang.String deviceName) {
		this.deviceName = deviceName;
	}
	
	/**
	 * 収集項目コードを取得します。
	 * @return 収集項目コード
	 */
	public java.lang.String getItemCode() {
		return itemCode;
	}
	
	/**
	 * 収集項目コードを設定します。
	 * @param itemCode 収集項目コード
	 */
	public void setItemCode(java.lang.String itemCode) {
		this.itemCode = itemCode;
	}
}

==> hinemos_src-3.1.0.tar.gz: Hinemos_src-3.1.0/PerformanceEJB/src/com/clustercontrol/performance/monitor/bean/MonitorPerfCheckInfo.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */
package com.clustercontrol.performance.monitor.bean;

import com.clustercontrol.monitor.run.bean.MonitorCheckInfo;

/**
 * リソース監視情報のBeanクラス<BR>
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class MonitorPerfCheckInfo extends MonitorCheckInfo
{
	protected java.lang.String collectorId;
	protected java.lang.String itemCode;
	protected Long deviceIndex; // 使用していない (ver3.1.0)
	protected java.lang.String deviceName; // 使用していない (ver3.1.0)
	protected java.lang.String displayName;
	
	public MonitorPerfCheckInfo()
	{
	}
	
	/**
	 * 収集IDを取得します。
	 * @return 収集ID
	 */
	public java.lang.String getCollectorId() {
		return collectorId;
	}
	
	/**
	 * 収集IDを設定します。
	 * @param collectorId 収集ID
	 */
	public void setCollectorId(java.lang.String collectorId) {
		this.collectorId = collectorId;
	}
	
	/**
	 * デバイスのインデックスを取得します。
	 * @return デバイスのインデックス
	 */
	public Long getDeviceIndex() {
		return deviceIndex;
	}
	
	/**
	 * デバイスのインデックスを設定します。
	 * @param deviceIndex デバイスのインデックス
	 */
	public void setDeviceIndex(Long deviceIndex) {
		this.deviceIndex = deviceIndex;
	}
	
	/**
	 * デバイス名を取得します。
	 * @return デバイス名
	 */
	public java.lang.String getDeviceName() {
		return deviceName;
	}
	
	/**
	 * デバイス名を設定します。
	 * @param deviceName デバイス名
	 */
	public void setDeviceName(java.lang.String deviceName) {
		this.deviceName = deviceName;
	}
	
	/**
	 * リポジトリ表示名を取得します。
	 * @return リポジトリ表示名
	 */
	public java.lang.String getDisplayName() {
		return displayName;
	}

	/**
	 * リポジトリ表示名を設定します。
	 * @param deviceName リポジトリ表示名
	 */
	public void setDisplayName(java.lang.String displayName) {
		this.displayName = displayName;
	}

	/**
	 * 収集項目コードを取得します。
	 * @return 収集項目コード
	 */
	public java.lang.String getItemCode() {
		return itemCode;
	}
	
	/**
	 * 収集項目コードを設定します。
	 * @param itemCode 収集項目コード
	 */
	public void setItemCode(java.lang.String itemCode) {
		this.itemCode = itemCode;
	}
}
